Learn R Programming

dejaVu (version 0.3.1)

extract_results: Extract the results of running a scenario

Description

This function is a wrapper around CreateScenario See the user guide vignette for an example of using this function

Usage

extract_results(answer, name, description)

Value

A Scenario object

Arguments

answer

A named list of lists

name

The name of the lists of answer which should be extracted and put together into a sc

description

The description parameter to be passed into the CreateScenario function

See Also

CreateScenario