Learn R Programming

dejaVu (version 0.3.1)

subjectsPerArm: S3 generic to output the number of subjects in each arm for a given object

Description

S3 generic to output the number of subjects in each arm for a given object

Usage

subjectsPerArm(x)

Value

A vector of the number of subjects in each arm

Arguments

x

The object

Examples

Run this code
sim <- SimulateComplete(study.time=365,number.subjects=50,
event.rates=c(0.01,0.005),dispersions=0.25)
subjectsPerArm(sim)

Run the code above in your browser using DataLab